@@ -13,3 +13,9 @@ dgebal <- function(A, job = c("B","N", "P","S")) {
     .Deprecated("balance")
     .Call("R_dgebal", A, match.arg(job))
 }
+
+## Not exported, used to make  'R CMD check <pkg>'  be faster *or* more extensive:
+doExtras <- function(int = interactive()) {
+    int || nzchar(Sys.getenv("R_expm_check_extra")) ||
+        identical("true", unname(Sys.getenv("R_PKG_CHECKING_doExtras")))
+}
