@@ -66,8 +66,7 @@ SEXP R_dgebal(SEXP x, SEXP type)
 	F77_CALL(dgebal)(typnm, &n, REAL(z), &n, INTEGER(i_1), INTEGER(i_2),
 			 REAL(Scale), &info FCONE);
 	if (info)
-	    error(_("LAPACK's dgebal(%s) returned info code %d"),
-		  typnm[0], info);
+	    error(_("LAPACK's dgebal(%s) returned info code %d"), typnm, info);
     }
 
     setAttrib(ans, R_NamesSymbol, nms);
@@ -75,4 +74,3 @@ SEXP R_dgebal(SEXP x, SEXP type)
     UNPROTECT(nprot);
     return ans;
 }
-
